from chat_downloader import ChatDownloader
import click


@click.command()
@click.option("--id", default="tvjxnPexKgU", help="The id of the video")
def get_chats(id):
    url = f"https://www.youtube.com/watch?v={id}"
    print(url)
    chat = ChatDownloader().get_chat(url)
    timestamps = []
    buffer = ""
    for m in chat:
        # print(chat.format(m))
        if "!timestamp" in m["message"]:
            timestamps.append(m)
            # print(chat.format(m))
    for m in timestamps:
        buffer = buffer + chat.format(m) + "\n"

    # Return the response in json format
    print(buffer)


if __name__ == '__main__':
    get_chats()


from setuptools import setup

REQUIREMENTS =['chat_downloader', 'click']

CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Internet',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python'
]

setup(
    name='ladyredhood-chats',
    version='0.1.1',
    description='A small script to extract timestamps from youtube chats',
    author='Aurghyadip Kundu',
    author_email='director@webedutech.org',
    license='MIT',
    url='https://github.com/aurghya-0/ladyredhood-chat',
    packages=['chats'],
    classifiers=CLASSIFIERS,
    install_requires=REQUIREMENTS,
    keywords='youtube youtube-chat youtube-timestamp'
)